#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['pyformatters_afp_quality']

package_data = \
{'': ['*']}

install_requires = \
['pymultirole-plugins>=0.7.0,<0.8.0',
 'pandas>=1.2.3,<=1.3.5',
 'openpyxl==3.0.7',
 'pytest',
 'spacy[lookups]==3.4.4',
 'collections-extended']

entry_points = \
{'pyformatters.plugins': ['afp_quality = '
                          'pyformatters_afp_quality.afp_quality:AFPQualityFormatter']}

setup(name='pyformatters-afp_quality',
      version='0.7.1',
      description='Sherpa AFP Quality formatter',
      author='Olivier Terrier',
      author_email='olivier.terrier@kairntech.com',
      url='https://kairntech.com/',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      entry_points=entry_points,
      python_requires='>=3.8',
     )
